import GPLinearODEMaker.powers_of_negative_one

"""
    m52_m52_kernel(hyperparameters, δ, dorder; shift_ind=0)

Created by kernel_coder(). Requires 3 hyperparameters.
Likely created using m52_m52_kernel_base() as an input.
Use with include("src/kernels/m52_m52_kernel.jl").

# Arguments
- `hyperparameters::Vector`: The hyperparameter values. For this kernel, they should be `["λ1", "λ2", "sratio"]`
- `δ::Real`: The difference between the inputs (e.g. `t1 - t2`)
- `dorder::Vector{<:Integer}`: How many times to differentiate with respect to the inputs and the `hyperparameters` (e.g. `dorder=[0, 1, 0, 2]` would correspond to differentiating once w.r.t the second input and twice w.r.t `hyperparameters[2]`)
- `shift_ind::Integer=0`: If changed, the index of which hyperparameter is the `δ` shifting one
"""
function m52_m52_kernel(
    hyperparameters::Vector{<:Real},
    δ::Real,
    dorder::Vector{<:Integer};
    shift_ind::Integer=0)

    include_shift = shift_ind!=0
    @assert length(hyperparameters)==3+Int(include_shift) "hyperparameters is the wrong length"
    dorder_len = 5 + Int(include_shift)
    @assert length(dorder)==dorder_len "dorder is the wrong length"
    @assert maximum(dorder) < 3 "No more than two derivatives for each time or hyperparameter can be calculated"

    dorder2 = dorder[2]
    dorder[2] += dorder[1]

    if include_shift
        dorder[2] += dorder[shift_ind+2]
        δ += hyperparameters[shift_ind]
        hyperparameters_view = view(hyperparameters, 1:4 .!= shift_ind)
        dorder_view = view(dorder, 2:dorder_len)
        dorder_view = view(dorder_view, 1:(dorder_len-1) .!= (shift_ind+1))
    else
        hyperparameters_view = hyperparameters
        dorder_view = view(dorder, 2:dorder_len)
    end

    λ1 = hyperparameters_view[1]
    λ2 = hyperparameters_view[2]
    sratio = hyperparameters_view[3]

    dabs_δ = powers_of_negative_one(δ < 0)  # store derivative of abs()
    abs_δ = abs(δ)

    if dorder_view==[6, 0, 0, 2]
        func = 2500.0*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^6/λ2^6 + 250.0*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 - 670.820393249937*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5
    end

    if dorder_view==[5, 0, 0, 2]
        func = -745.35599249993*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^5/λ2^5 - 111.80339887499*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 + 250.0*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4
    end

    if dorder_view==[4, 0, 0, 2]
        func = 200.0*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^4/λ2^4 + 50.0*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 89.4427190999916*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3
    end

    if dorder_view==[3, 0, 0, 2]
        func = -44.7213595499958*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^3/λ2^3 - 22.3606797749979*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 + 30.0*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2
    end

    if dorder_view==[2, 0, 0, 2]
        func = 6.66666666666667*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^2/λ2^2 + 10.0*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2 - 8.94427190999916*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2
    end

    if dorder_view==[1, 0, 0, 2]
        func = 2*exp(-2.23606797749979*abs_δ/λ2)*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2) - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2
    end

    if dorder_view==[0, 0, 0, 2]
        func = 2*exp(-2.23606797749979*abs_δ/λ2)*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)
    end

    if dorder_view==[6, 0, 1, 1]
        func = -15000.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^6/λ2^7 + 5590.16994374948*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^6/λ2^8 - 1500.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7 + 3354.10196624969*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 + 250.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^6*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^6 - 670.820393249937*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^5*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^5 + 559.016994374948*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^8 - 1500.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7
    end

    if dorder_view==[5, 0, 1, 1]
        func = 3726.77996249965*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^5/λ2^6 - 1666.66666666667*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^5/λ2^7 + 559.016994374948*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 - 1000.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 - 111.80339887499*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^5*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^5 + 250.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^4*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^4 - 250.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7 + 559.016994374948*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6
    end

    if dorder_view==[4, 0, 1, 1]
        func = -800.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^4/λ2^5 + 447.213595499958*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^4/λ2^6 - 200.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 + 268.328157299975*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 + 50.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^4*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^4 - 89.4427190999916*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^3*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^3 + 111.80339887499*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 - 200.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5
    end

    if dorder_view==[3, 0, 1, 1]
        func = 134.164078649987*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^3/λ2^4 - 100.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^3/λ2^5 + 67.0820393249937*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 60.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 - 22.3606797749979*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^3*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^3 + 30.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^2*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^2 - 50.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 + 67.0820393249937*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4
    end

    if dorder_view==[2, 0, 1, 1]
        func = -13.3333333333333*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^2/λ2^3 + 14.9071198499986*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^2/λ2^4 - 20.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 + 8.94427190999916*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2 + 10.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^2*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^2 - 8.94427190999916*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2 + 22.3606797749979*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 20.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3
    end

    if dorder_view==[1, 0, 1, 1]
        func = 2*exp(-2.23606797749979*abs_δ/λ2)*sratio*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2) + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2 + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2 - 10.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3
    end

    if dorder_view==[0, 0, 1, 1]
        func = 2*exp(-2.23606797749979*abs_δ/λ2)*sratio*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2) + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2
    end

    if dorder_view==[6, 1, 0, 1]
        func = 0
    end

    if dorder_view==[5, 1, 0, 1]
        func = 0
    end

    if dorder_view==[4, 1, 0, 1]
        func = 0
    end

    if dorder_view==[3, 1, 0, 1]
        func = 0
    end

    if dorder_view==[2, 1, 0, 1]
        func = 0
    end

    if dorder_view==[1, 1, 0, 1]
        func = 0
    end

    if dorder_view==[0, 1, 0, 1]
        func = 0
    end

    if dorder_view==[6, 0, 0, 1]
        func = 2500.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^6/λ2^6 + 250.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 - 670.820393249937*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5
    end

    if dorder_view==[5, 0, 0, 1]
        func = -745.35599249993*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^5/λ2^5 - 111.80339887499*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 + 250.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4
    end

    if dorder_view==[4, 0, 0, 1]
        func = 200.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^4/λ2^4 + 50.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 89.4427190999916*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3
    end

    if dorder_view==[3, 0, 0, 1]
        func = -44.7213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^3/λ2^3 - 22.3606797749979*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 + 30.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2
    end

    if dorder_view==[2, 0, 0, 1]
        func = 6.66666666666667*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^2/λ2^2 + 10.0*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2 - 8.94427190999916*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2
    end

    if dorder_view==[1, 0, 0, 1]
        func = 2*exp(-2.23606797749979*abs_δ/λ2)*sratio*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2) - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2
    end

    if dorder_view==[0, 0, 0, 1]
        func = 2*exp(-2.23606797749979*abs_δ/λ2)*sratio*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)
    end

    if dorder_view==[6, 0, 2, 0]
        func = 52500.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^6/λ2^8 + 6250.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^6/λ2^10 - 39131.1896062463*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^6/λ2^9 + 5250.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^8 - 10062.3058987491*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7 - 1500.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^6*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^7 + 3354.10196624969*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^6 + 125.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^6*(6.66666666666667*abs_δ^2/λ2^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2^6 - 335.410196624969*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(16.6666666666667*abs_δ*dabs_δ/λ2^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2^5 + 625.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^10 - 3913.11896062463*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^9 - 1677.05098312484*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^9 + 9000.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^8 + 559.016994374948*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^6*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^8 - 1500.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^5*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^7
    end

    if dorder_view==[5, 0, 2, 0]
        func = -11180.339887499*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5/λ2^7 - 1863.38998124983*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^5/λ2^9 + 10000.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^5/λ2^8 - 1677.05098312484*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7 + 2500.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 + 559.016994374948*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^6 - 1000.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^5 - 55.9016994374948*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(6.66666666666667*abs_δ^2/λ2^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2^5 + 125.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(16.6666666666667*abs_δ*dabs_δ/λ2^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2^4 - 279.508497187474*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^9 + 1500.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^8 + 625.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^8 - 2795.08497187474*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7 - 250.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^5*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^7 + 559.016994374948*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^4*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^6
    end

    if dorder_view==[4, 0, 2, 0]
        func = 2000.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4/λ2^6 + 500.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^4/λ2^8 - 2236.06797749979*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^4/λ2^7 + 500.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 - 536.65631459995*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 - 200.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^5 + 268.328157299975*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^4 + 25.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(6.66666666666667*abs_δ^2/λ2^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2^4 - 44.7213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(16.6666666666667*abs_δ*dabs_δ/λ2^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2^3 + 125.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^8 - 559.016994374948*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7 - 223.606797749979*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7 + 800.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 + 111.80339887499*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^4*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^6 - 200.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^3*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^5
    end

    if dorder_view==[3, 0, 2, 0]
        func = -268.328157299975*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3/λ2^5 - 111.80339887499*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^3/λ2^7 + 400.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^3/λ2^6 - 134.164078649987*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 + 90.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 + 67.0820393249937*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^4 - 60.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^3 - 11.180339887499*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(6.66666666666667*abs_δ^2/λ2^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2^3 + 15.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(16.6666666666667*abs_δ*dabs_δ/λ2^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2^2 - 55.9016994374948*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7 + 200.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 + 75.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 - 201.246117974981*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 - 50.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^3*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^5 + 67.0820393249937*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^2*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^4
    end

    if dorder_view==[2, 0, 2, 0]
        func = 20.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2/λ2^4 + 16.6666666666667*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^2/λ2^6 - 44.7213595499958*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^2/λ2^5 + 30.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 8.94427190999916*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 - 20.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^3 + 8.94427190999916*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^2 + 5.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(6.66666666666667*abs_δ^2/λ2^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2^2 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(16.6666666666667*abs_δ*dabs_δ/λ2^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2 + 25.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 - 67.0820393249937*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 - 22.3606797749979*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 + 40.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 + 22.3606797749979*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^2*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^4 - 20.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^3
    end

    if dorder_view==[1, 0, 2, 0]
        func = exp(-2.23606797749979*abs_δ/λ2)*sratio^2*(16.6666666666667*abs_δ*dabs_δ/λ2^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3) + 5.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^2 + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^2 - 2.23606797749979*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(6.66666666666667*abs_δ^2/λ2^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3)/λ2 - 11.180339887499*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 + 20.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 10.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^3
    end

    if dorder_view==[0, 0, 2, 0]
        func = exp(-2.23606797749979*abs_δ/λ2)*sratio^2*(6.66666666666667*abs_δ^2/λ2^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^3) + 5.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ^2*sratio^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^2
    end

    if dorder_view==[6, 1, 1, 0]
        func = 0
    end

    if dorder_view==[5, 1, 1, 0]
        func = 0
    end

    if dorder_view==[4, 1, 1, 0]
        func = 0
    end

    if dorder_view==[3, 1, 1, 0]
        func = 0
    end

    if dorder_view==[2, 1, 1, 0]
        func = 0
    end

    if dorder_view==[1, 1, 1, 0]
        func = 0
    end

    if dorder_view==[0, 1, 1, 0]
        func = 0
    end

    if dorder_view==[6, 0, 1, 0]
        func = -7500.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^6/λ2^7 + 2795.08497187474*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^6/λ2^8 - 750.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7 + 1677.05098312484*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 + 125.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^6*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^6 - 335.410196624969*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^5 + 279.508497187474*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^8 - 750.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7
    end

    if dorder_view==[5, 0, 1, 0]
        func = 1863.38998124983*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5/λ2^6 - 833.333333333334*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^5/λ2^7 + 279.508497187474*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 - 500.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 - 55.9016994374948*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^5 + 125.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^4 - 125.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^7 + 279.508497187474*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6
    end

    if dorder_view==[4, 0, 1, 0]
        func = -400.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4/λ2^5 + 223.606797749979*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^4/λ2^6 - 100.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 + 134.164078649987*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 + 25.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^4 - 44.7213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^3 + 55.9016994374948*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 - 100.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5
    end

    if dorder_view==[3, 0, 1, 0]
        func = 67.0820393249937*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3/λ2^4 - 50.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^3/λ2^5 + 33.5410196624969*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 30.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 - 11.180339887499*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^3 + 15.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^2 - 25.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 + 33.5410196624969*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4
    end

    if dorder_view==[2, 0, 1, 0]
        func = -6.66666666666667*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2/λ2^3 + 7.4535599249993*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^2/λ2^4 - 10.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2 + 5.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2^2 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2 + 11.180339887499*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 10.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3
    end

    if dorder_view==[1, 0, 1, 0]
        func = exp(-2.23606797749979*abs_δ/λ2)*sratio^2*(-5.0*abs_δ*dabs_δ/λ2^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2) + 2.23606797749979*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2 + 2.23606797749979*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2 - 2.23606797749979*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2)/λ2 - 5.0*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3
    end

    if dorder_view==[0, 0, 1, 0]
        func = exp(-2.23606797749979*abs_δ/λ2)*sratio^2*(-1.66666666666667*abs_δ^2/λ2^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2^2) + 2.23606797749979*exp(-2.23606797749979*abs_δ/λ2)*abs_δ*sratio^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2
    end

    if dorder_view==[6, 2, 0, 0]
        func = 52500.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^6/λ1^8 + 6250.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^6/λ1^10 - 39131.1896062463*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^6/λ1^9 + 5250.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^8 - 10062.3058987491*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^7 - 1500.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^6*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^7 + 3354.10196624969*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^6 + 125.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^6*(6.66666666666667*abs_δ^2/λ1^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1^6 - 335.410196624969*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(16.6666666666667*abs_δ*dabs_δ/λ1^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1^5 + 625.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^10 - 3913.11896062463*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^9 - 1677.05098312484*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^9 + 9000.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^8 + 559.016994374948*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^6*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^8 - 1500.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^5*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^7
    end

    if dorder_view==[5, 2, 0, 0]
        func = -11180.339887499*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5/λ1^7 - 1863.38998124983*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^5/λ1^9 + 10000.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^5/λ1^8 - 1677.05098312484*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^7 + 2500.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6 + 559.016994374948*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^6 - 1000.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^5 - 55.9016994374948*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(6.66666666666667*abs_δ^2/λ1^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1^5 + 125.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(16.6666666666667*abs_δ*dabs_δ/λ1^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1^4 - 279.508497187474*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^9 + 1500.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^8 + 625.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^8 - 2795.08497187474*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^7 - 250.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^5*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^7 + 559.016994374948*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^4*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^6
    end

    if dorder_view==[4, 2, 0, 0]
        func = 2000.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4/λ1^6 + 500.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^4/λ1^8 - 2236.06797749979*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^4/λ1^7 + 500.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6 - 536.65631459995*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 - 200.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^5 + 268.328157299975*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^4 + 25.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(6.66666666666667*abs_δ^2/λ1^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1^4 - 44.7213595499958*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(16.6666666666667*abs_δ*dabs_δ/λ1^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1^3 + 125.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^8 - 559.016994374948*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^7 - 223.606797749979*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^7 + 800.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6 + 111.80339887499*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^4*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^6 - 200.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^3*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^5
    end

    if dorder_view==[3, 2, 0, 0]
        func = -268.328157299975*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3/λ1^5 - 111.80339887499*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^3/λ1^7 + 400.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^3/λ1^6 - 134.164078649987*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 + 90.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 + 67.0820393249937*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^4 - 60.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^3 - 11.180339887499*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(6.66666666666667*abs_δ^2/λ1^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1^3 + 15.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(16.6666666666667*abs_δ*dabs_δ/λ1^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1^2 - 55.9016994374948*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^7 + 200.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6 + 75.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6 - 201.246117974981*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 - 50.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^3*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^5 + 67.0820393249937*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^2*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^4
    end

    if dorder_view==[2, 2, 0, 0]
        func = 20.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2/λ1^4 + 16.6666666666667*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^2/λ1^6 - 44.7213595499958*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^2/λ1^5 + 30.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 - 8.94427190999916*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^3 - 20.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^3 + 8.94427190999916*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^2 + 5.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(6.66666666666667*abs_δ^2/λ1^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1^2 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(16.6666666666667*abs_δ*dabs_δ/λ1^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1 + 25.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6 - 67.0820393249937*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 - 22.3606797749979*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 + 40.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 + 22.3606797749979*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^2*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^4 - 20.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^3
    end

    if dorder_view==[1, 2, 0, 0]
        func = exp(-2.23606797749979*abs_δ/λ1)*(16.6666666666667*abs_δ*dabs_δ/λ1^4 + 4.47213595499958*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3) + 5.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^3 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^3 + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^2 + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^2 - 2.23606797749979*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(6.66666666666667*abs_δ^2/λ1^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3)/λ1 - 11.180339887499*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 + 20.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 - 10.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^3
    end

    if dorder_view==[0, 2, 0, 0]
        func = exp(-2.23606797749979*abs_δ/λ1)*(6.66666666666667*abs_δ^2/λ1^4 + 4.47213595499958*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^3) + 5.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^3 + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^2
    end

    if dorder_view==[6, 1, 0, 0]
        func = -7500.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^6/λ1^7 + 2795.08497187474*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^6/λ1^8 - 750.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^7 + 1677.05098312484*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6 + 125.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^6*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^6 - 335.410196624969*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^5 + 279.508497187474*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^8 - 750.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^7
    end

    if dorder_view==[5, 1, 0, 0]
        func = 1863.38998124983*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5/λ1^6 - 833.333333333334*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^5/λ1^7 + 279.508497187474*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6 - 500.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 - 55.9016994374948*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^5 + 125.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^4 - 125.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^7 + 279.508497187474*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6
    end

    if dorder_view==[4, 1, 0, 0]
        func = -400.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4/λ1^5 + 223.606797749979*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^4/λ1^6 - 100.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 + 134.164078649987*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 + 25.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^4 - 44.7213595499958*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^3 + 55.9016994374948*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6 - 100.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5
    end

    if dorder_view==[3, 1, 0, 0]
        func = 67.0820393249937*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3/λ1^4 - 50.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^3/λ1^5 + 33.5410196624969*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 - 30.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^3 - 11.180339887499*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^3 + 15.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^2 - 25.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 + 33.5410196624969*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4
    end

    if dorder_view==[2, 1, 0, 0]
        func = -6.66666666666667*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2/λ1^3 + 7.4535599249993*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^2/λ1^4 - 10.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^3 + 4.47213595499958*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^2 + 5.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1^2 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1 + 11.180339887499*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 - 10.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^3
    end

    if dorder_view==[1, 1, 0, 0]
        func = exp(-2.23606797749979*abs_δ/λ1)*(-5.0*abs_δ*dabs_δ/λ1^3 - 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2) + 2.23606797749979*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^2 + 2.23606797749979*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^2 - 2.23606797749979*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2)/λ1 - 5.0*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^3
    end

    if dorder_view==[0, 1, 0, 0]
        func = exp(-2.23606797749979*abs_δ/λ1)*(-1.66666666666667*abs_δ^2/λ1^3 - 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1^2) + 2.23606797749979*exp(-2.23606797749979*abs_δ/λ1)*abs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^2
    end

    if dorder_view==[6, 0, 0, 0]
        func = 1250.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^6/λ1^6 + 125.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^6 - 335.410196624969*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 + 1250.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^6/λ2^6 + 125.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^6*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^6 - 335.410196624969*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5
    end

    if dorder_view==[5, 0, 0, 0]
        func = -372.677996249965*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5/λ1^5 - 55.9016994374948*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^5 + 125.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 - 372.677996249965*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5/λ2^5 - 55.9016994374948*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^5*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^5 + 125.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4
    end

    if dorder_view==[4, 0, 0, 0]
        func = 100.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4/λ1^4 + 25.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^4 - 44.7213595499958*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^3 + 100.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4/λ2^4 + 25.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^4*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^4 - 44.7213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3
    end

    if dorder_view==[3, 0, 0, 0]
        func = -22.3606797749979*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3/λ1^3 - 11.180339887499*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^3 + 15.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^2 - 22.3606797749979*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3/λ2^3 - 11.180339887499*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^3*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^3 + 15.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2
    end

    if dorder_view==[2, 0, 0, 0]
        func = 3.33333333333333*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2/λ1^2 + 5.0*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1^2 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1 + 3.33333333333333*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2/λ2^2 + 5.0*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2^2 - 4.47213595499958*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2
    end

    if dorder_view==[1, 0, 0, 0]
        func = exp(-2.23606797749979*abs_δ/λ1)*(1.66666666666667*abs_δ*dabs_δ/λ1^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1) + exp(-2.23606797749979*abs_δ/λ2)*sratio^2*(1.66666666666667*abs_δ*dabs_δ/λ2^2 + 2.23606797749979*dabs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2) - 2.23606797749979*exp(-2.23606797749979*abs_δ/λ1)*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1)/λ1 - 2.23606797749979*exp(-2.23606797749979*abs_δ/λ2)*sratio^2*dabs_δ*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)/λ2
    end

    if dorder_view==[0, 0, 0, 0]
        func = exp(-2.23606797749979*abs_δ/λ1)*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ1)/λ1) + exp(-2.23606797749979*abs_δ/λ2)*sratio^2*(1 + 2.23606797749979*abs_δ*(1 + 0.74535599249993*abs_δ/λ2)/λ2)
    end

    dorder[2] = dorder2  # resetting dorder[2]
    return powers_of_negative_one(dorder2) * float(func)  # correcting for amount of t2 derivatives

end


return m52_m52_kernel, 3  # the function handle and the number of kernel hyperparameters
