import GPLinearODEMaker.powers_of_negative_one

"""
    rm52_kernel(hyperparameters, δ, dorder; shift_ind=0)

Created by kernel_coder(). Requires 2 hyperparameters.
Likely created using rm52_kernel_base() as an input.
Use with include("src/kernels/rm52_kernel.jl").

# Arguments
- `hyperparameters::Vector`: The hyperparameter values. For this kernel, they should be `["α", "μ"]`
- `δ::Real`: The difference between the inputs (e.g. `t1 - t2`)
- `dorder::Vector{<:Integer}`: How many times to differentiate with respect to the inputs and the `hyperparameters` (e.g. `dorder=[0, 1, 0, 2]` would correspond to differentiating once w.r.t the second input and twice w.r.t `hyperparameters[2]`)
- `shift_ind::Integer=0`: If changed, the index of which hyperparameter is the `δ` shifting one
"""
function rm52_kernel(
    hyperparameters::Vector{<:Real},
    δ::Real,
    dorder::Vector{<:Integer};
    shift_ind::Integer=0)

    include_shift = shift_ind!=0
    @assert length(hyperparameters)==2+Int(include_shift) "hyperparameters is the wrong length"
    dorder_len = 4 + Int(include_shift)
    @assert length(dorder)==dorder_len "dorder is the wrong length"
    @assert maximum(dorder) < 3 "No more than two derivatives for each time or hyperparameter can be calculated"

    dorder2 = dorder[2]
    dorder[2] += dorder[1]

    if include_shift
        dorder[2] += dorder[shift_ind+2]
        δ += hyperparameters[shift_ind]
        hyperparameters_view = view(hyperparameters, 1:3 .!= shift_ind)
        dorder_view = view(dorder, 2:dorder_len)
        dorder_view = view(dorder_view, 1:(dorder_len-1) .!= (shift_ind+1))
    else
        hyperparameters_view = hyperparameters
        dorder_view = view(dorder, 2:dorder_len)
    end

    α = hyperparameters_view[1]
    μ = hyperparameters_view[2]

    dabs_δ = powers_of_negative_one(δ < 0)  # store derivative of abs()
    abs_δ = abs(δ)

    if dorder_view==[6, 0, 2]
        func = 2012.46117974981*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 - 1341.64078649987*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 750.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 - 500.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^3 + 2012.46117974981*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^5 - 670.820393249937*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 2500.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 2236.06797749979*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*abs_δ*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 750.0*α*(-6 - α)*(-7 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^5 - 250.0*α*(-6 - α)*(-7 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^4 + 335.410196624969*α^2*(-6 - α)*(-7 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^6 + 1250.0*α^2*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 416.666666666667*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*abs_δ^2*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 125.0*α^2*(-6 - α)*(-7 - α)*(-8 - α)*(-9 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-10 - α)/μ^6
    end

    if dorder_view==[5, 0, 2]
        func = 750.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 - 500.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 4.54747350886464e-13*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 - 223.606797749979*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 750.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^5 - 250.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 745.355992499931*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 833.333333333334*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*abs_δ*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 335.410196624969*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^5 - 111.80339887499*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 125.0*α^2*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^6 + 372.677996249965*α^2*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 186.338998124983*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*abs_δ^2*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 55.9016994374948*α^2*(-6 - α)*(-7 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^6
    end

    if dorder_view==[4, 0, 2]
        func = 268.328157299975*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 - 178.885438199983*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 8.5265128291212e-14*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 150.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 - 100.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 268.328157299975*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^5 - 89.4427190999916*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 + 200.0*α*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 298.142396999972*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*abs_δ*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 150.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^5 - 50.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 44.7213595499958*α^2*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^6 + 100.0*α^2*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 + 83.3333333333334*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*abs_δ^2*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 25.0*α^2*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^6
    end

    if dorder_view==[3, 0, 2]
        func = 90.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 - 60.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 + 67.0820393249937*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 - 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 90.0*α*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^5 - 30.0*α*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 + 44.7213595499958*α*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 + 100.0*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*abs_δ*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 67.0820393249937*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^5 - 22.3606797749979*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^3*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 + 15.0*α^2*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^6 + 22.3606797749979*α^2*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 + 37.2677996249965*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*abs_δ^2*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 11.180339887499*α^2*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^6
    end

    if dorder_view==[2, 0, 2]
        func = 26.8328157299975*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4 - 17.8885438199983*(-2 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 + 30.0*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 - 20.0*(-2 - α)*(-3 - α)*dabs_δ^2*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 + 26.8328157299975*α*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^5 - 8.94427190999916*α*(-2 - α)*(-3 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 + 6.66666666666667*α*(-2 - α)*(1 + α)*(3 + α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 + 29.8142396999972*(-2 - α)*(1 + α)*(3 + α)*abs_δ*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 30.0*α*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^5 - 10.0*α*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^2*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 + 4.47213595499958*α^2*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^6 + 3.33333333333333*α^2*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 + 16.6666666666667*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*abs_δ^2*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 5.0*α^2*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^6
    end

    if dorder_view==[1, 0, 2]
        func = 6*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^4 - 4*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^3 + 6*α*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^5 - 2*α*(-2 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4 + 13.4164078649987*(-2 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4 - 8.94427190999916*(-2 - α)*dabs_δ*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 + α^2*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^6 + 6.66666666666667*(1 + α)*(3 + α)*abs_δ*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + 13.4164078649987*α*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^5 - 4.47213595499958*α*(-2 - α)*(-3 - α)*dabs_δ*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 + 7.4535599249993*(-2 - α)*(1 + α)*(3 + α)*abs_δ^2*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 2.23606797749979*α^2*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^6
    end

    if dorder_view==[0, 0, 2]
        func = 6*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^4 - 4*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^3 + 6*α*(-2 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^5 - 2*α*(-2 - α)*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4 + 3.33333333333333*(1 + α)*(3 + α)*abs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + α^2*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^6
    end

    if dorder_view==[6, 1, 1]
        func = 670.820393249937*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 670.820393249937*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 670.820393249937*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 - 335.410196624969*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 335.410196624969*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 335.410196624969*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 375.0*(6.66666666666667*μ*(1 + α)*dabs_δ^2 + 6.66666666666667*μ*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 750.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 250.0*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^3 + 250.0*(-6 - α)*(-7 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^3 + 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^3 + 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^3 + 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^3 + 250.0*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^3 - 670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 - 125.0*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*(-6 - α)*(-7 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-5 - α)*dabs_δ^6*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^6*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*dabs_δ + 2.23606797749979*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*abs_δ*dabs_δ + 6.66666666666667*μ*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 1250.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-6 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-6 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2)) + 335.410196624969*α*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 335.410196624969*α*(-6 - α)*(-7 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 335.410196624969*α*(-6 - α)*(-7 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 335.410196624969*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 335.410196624969*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 1250.0*α*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 1250.0*α*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 1250.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 1250.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^3 - 670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)*(2.23606797749979*α*abs_δ + 2.23606797749979*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*abs_δ^2 + 3.33333333333333*μ*(3 + α)*abs_δ^2)/μ^2 + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-7 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-7 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 375.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 125.0*α*(-7 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^4 + 125.0*α*(-6 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^4 + 125.0*α*(-6 - α)*(-7 - α)*(-8 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^4 + 125.0*α*(-6 - α)*(-7 - α)*(-8 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^4 + 125.0*α*(-6 - α)*(-7 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^4 + 125.0*α*(-6 - α)*(-7 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^4 - 335.410196624969*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 - 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^3 + 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-8 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-8 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^6*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*α*(-6 - α)*(-7 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^4 - 335.410196624969*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 - 1250.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 125.0*α*(-6 - α)*(-7 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^4
    end

    if dorder_view==[5, 1, 1]
        func = 250.0*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 250.0*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 250.0*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 250.0*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 - 125.0*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 125.0*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 125.0*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 111.80339887499*(6.66666666666667*μ*(1 + α)*dabs_δ^2 + 6.66666666666667*μ*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 223.606797749979*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 111.80339887499*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 111.80339887499*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 111.80339887499*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 - 250.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 - 55.9016994374948*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 55.9016994374948*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*dabs_δ^5*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^5*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 55.9016994374948*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*dabs_δ + 2.23606797749979*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*abs_δ*dabs_δ + 6.66666666666667*μ*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 372.677996249965*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-5 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-5 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2)) + 125.0*α*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 125.0*α*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 125.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 125.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 372.677996249965*α*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 372.677996249965*α*(-2 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 372.677996249965*α*(-2 - α)*(-3 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 - 250.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)*(2.23606797749979*α*abs_δ + 2.23606797749979*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*abs_δ^2 + 3.33333333333333*μ*(3 + α)*abs_δ^2)/μ^2 + 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-6 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-6 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 111.80339887499*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 + 55.9016994374948*α*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 55.9016994374948*α*(-6 - α)*(-7 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 55.9016994374948*α*(-6 - α)*(-7 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 55.9016994374948*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 + 55.9016994374948*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 - 125.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 - 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-7 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-7 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 55.9016994374948*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 - 125.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 - 372.677996249965*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 55.9016994374948*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4
    end

    if dorder_view==[4, 1, 1]
        func = 89.4427190999916*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 89.4427190999916*(-2 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 89.4427190999916*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 - 44.7213595499958*(-3 - α)*(-4 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 44.7213595499958*(-2 - α)*(-4 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 44.7213595499958*(-2 - α)*(-3 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 30.0*(6.66666666666667*μ*(1 + α)*dabs_δ^2 + 6.66666666666667*μ*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 60.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 + 50.0*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 50.0*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 50.0*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 50.0*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 - 89.4427190999916*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 - 25.0*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 25.0*(-2 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 25.0*(-2 - α)*(-3 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 25.0*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^4*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*dabs_δ + 2.23606797749979*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*abs_δ*dabs_δ + 6.66666666666667*μ*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 100.0*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-4 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-4 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2)) + 44.7213595499958*α*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 + 44.7213595499958*α*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 + 44.7213595499958*α*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 + 100.0*α*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 100.0*α*(-2 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 50.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 - 89.4427190999916*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)*(2.23606797749979*α*abs_δ + 2.23606797749979*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*abs_δ^2 + 3.33333333333333*μ*(3 + α)*abs_δ^2)/μ^2 + 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-5 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-5 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 30.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*α*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 + 25.0*α*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 25.0*α*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 25.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 + 25.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 - 44.7213595499958*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 - 50.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-6 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-6 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 25.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 - 44.7213595499958*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 - 100.0*α*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 25.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4
    end

    if dorder_view==[3, 1, 1]
        func = 30.0*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 + 30.0*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 - 15.0*(-3 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 15.0*(-2 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 6.70820393249937*(6.66666666666667*μ*(1 + α)*dabs_δ^2 + 6.66666666666667*μ*(3 + α)*dabs_δ^2)*(-2 - α)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 13.4164078649987*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 + 22.3606797749979*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 22.3606797749979*(-2 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 22.3606797749979*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 - 30.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 - 11.180339887499*(-3 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 11.180339887499*(-2 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 11.180339887499*(-2 - α)*(-3 - α)*dabs_δ^3*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 15.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*dabs_δ + 2.23606797749979*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*abs_δ*dabs_δ + 6.66666666666667*μ*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 22.3606797749979*(-2 - α)*(1 + α)*(3 + α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-3 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-3 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-3 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2)) + 15.0*α*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 + 15.0*α*(-2 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 + 22.3606797749979*α*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 22.3606797749979*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^3*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 - 30.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 + 11.180339887499*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)*(2.23606797749979*α*abs_δ + 2.23606797749979*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*abs_δ^2 + 3.33333333333333*μ*(3 + α)*abs_δ^2)/μ^2 + 15.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-4 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-4 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 15.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 6.70820393249937*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*α*(-2 - α)*(-3 - α)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 + 11.180339887499*α*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 + 11.180339887499*α*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 + 11.180339887499*α*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 - 15.0*α*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 - 22.3606797749979*(-2 - α)*(-3 - α)*(-4 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 11.180339887499*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-5 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-5 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 11.180339887499*(-2 - α)*(-3 - α)*(-4 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 11.180339887499*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^3*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 - 15.0*α*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 - 22.3606797749979*α*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 11.180339887499*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4
    end

    if dorder_view==[2, 1, 1]
        func = (6.66666666666667*μ*(1 + α)*dabs_δ^2 + 6.66666666666667*μ*(3 + α)*dabs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 - 2*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^3 + 8.94427190999916*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 - 4.47213595499958*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 10.0*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 + 10.0*(-2 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 - 8.94427190999916*(-2 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 - 5.0*(-3 - α)*dabs_δ^2*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 5.0*(-2 - α)*dabs_δ^2*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 4.47213595499958*(-2 - α)*(2.23606797749979*α*dabs_δ + 2.23606797749979*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*abs_δ*dabs_δ + 6.66666666666667*μ*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 3.33333333333333*(1 + α)*(3 + α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-2 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-2 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-2 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2)) - (3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*α*(-2 - α)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4 + 4.47213595499958*α*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 - 10.0*(-2 - α)*(-3 - α)*dabs_δ^2*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 - 8.94427190999916*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 + 5.0*(-2 - α)*(-3 - α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)*(2.23606797749979*α*abs_δ + 2.23606797749979*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*abs_δ^2 + 3.33333333333333*μ*(3 + α)*abs_δ^2)/μ^2 + 4.47213595499958*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-3 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-3 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 4.47213595499958*(-2 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 5.0*α*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 + 5.0*α*(-2 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 - 4.47213595499958*α*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 - 10.0*(-2 - α)*(-3 - α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 + 5.0*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-4 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-4 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 5.0*(-2 - α)*(-3 - α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 5.0*α*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^2*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 - 4.47213595499958*α*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 - 3.33333333333333*α*(-2 - α)*(1 + α)*(3 + α)*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 5.0*α*(-2 - α)*(-3 - α)*(-4 - α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4
    end

    if dorder_view==[1, 1, 1]
        func = -2*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^3 + (2.23606797749979*α*dabs_δ + 2.23606797749979*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*abs_δ*dabs_δ + 6.66666666666667*μ*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + 4.47213595499958*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 - 2*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^3 - 2.23606797749979*dabs_δ*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + (2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-2 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-2 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + (2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 - α*(-2 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4 - 4.47213595499958*(-2 - α)*dabs_δ*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 + 2.23606797749979*(-2 - α)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)*(2.23606797749979*α*abs_δ + 2.23606797749979*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*abs_δ^2 + 3.33333333333333*μ*(3 + α)*abs_δ^2)/μ^2 + 2.23606797749979*α*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 - α*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4 - 4.47213595499958*(-2 - α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 + 2.23606797749979*(-2 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-3 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-3 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + 2.23606797749979*(-2 - α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 2.23606797749979*α*(-2 - α)*(-3 - α)*dabs_δ*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 - 2.23606797749979*α*(-2 - α)*(-3 - α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4
    end

    if dorder_view==[0, 1, 1]
        func = -2*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^3 + (2.23606797749979*abs_δ + α/μ)^(-2 - α)*(2.23606797749979*α*abs_δ + 2.23606797749979*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*abs_δ^2 + 3.33333333333333*μ*(3 + α)*abs_δ^2)/μ^2 - 2*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^3 + (α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)*(α/(μ^2*(2.23606797749979*abs_δ + α/μ)) - (-2 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)) + α*(-2 - α)/(μ^3*(2.23606797749979*abs_δ + α/μ)^2))/μ^2 + ((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 - α*(-2 - α)*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4 - α*(-2 - α)*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4
    end

    if dorder_view==[6, 0, 1]
        func = -670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^3 + 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 335.410196624969*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4 - 1250.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 125.0*α*(-6 - α)*(-7 - α)*(-8 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-9 - α)/μ^4
    end

    if dorder_view==[5, 0, 1]
        func = -250.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^3 + 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 125.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4 - 372.677996249965*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 55.9016994374948*α*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^4
    end

    if dorder_view==[4, 0, 1]
        func = -89.4427190999916*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 50.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^3 + 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 44.7213595499958*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4 - 100.0*α*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 25.0*α*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^4
    end

    if dorder_view==[3, 0, 1]
        func = -30.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 + 15.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 22.3606797749979*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^3 + 11.180339887499*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 15.0*α*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4 - 22.3606797749979*α*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 11.180339887499*α*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^4
    end

    if dorder_view==[2, 0, 1]
        func = -8.94427190999916*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 + 4.47213595499958*(-2 - α)*(2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 10.0*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^3 + 5.0*(-2 - α)*(-3 - α)*dabs_δ^2*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 4.47213595499958*α*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4 - 3.33333333333333*α*(-2 - α)*(1 + α)*(3 + α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 5.0*α*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^4
    end

    if dorder_view==[1, 0, 1]
        func = -2*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^3 + (2.23606797749979*α*(2 + α)*dabs_δ + 6.66666666666667*μ*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 - α*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4 - 4.47213595499958*(-2 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^3 + 2.23606797749979*(-2 - α)*dabs_δ*(2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 2.23606797749979*α*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^4
    end

    if dorder_view==[0, 0, 1]
        func = -2*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^3 + (2.23606797749979*α*(2 + α)*abs_δ + 3.33333333333333*μ*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 - α*(-2 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^4
    end

    if dorder_view==[6, 2, 0]
        func = 2500.0*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 2500.0*(-3 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 2500.0*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 2500.0*(-2 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 2500.0*(-2 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 2500.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 2500.0*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 670.820393249937*(-6 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 670.820393249937*(-6 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 670.820393249937*(-6 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 670.820393249937*(-6 - α)*(-2 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 670.820393249937*(-6 - α)*(-2 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 670.820393249937*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 670.820393249937*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 670.820393249937*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 670.820393249937*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 750.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 750.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 750.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 750.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 250.0*(-7 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-7 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-7 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-6 - α)*(-7 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-6 - α)*(-7 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-6 - α)*(-7 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 670.820393249937*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 250.0*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 670.820393249937*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 250.0*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 250.0*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 250.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 670.820393249937*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 2500.0*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) - 2500.0*(-2 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) - 2500.0*(-2 - α)*(-3 - α)*(-5 - α)*(1 + α)*(3 + α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) - 2500.0*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) - 250.0*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 250.0*(-6 - α)*(-7 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-5 - α)*dabs_δ^6*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^6*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 670.820393249937*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 670.820393249937*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)*(4.47213595499958*μ*dabs_δ + 6.66666666666667*μ^2*abs_δ*dabs_δ)/μ^2 - 250.0*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 670.820393249937*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 1250.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-6 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 1250.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 750.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 250.0*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 250.0*(-6 - α)*(-7 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-4 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2 + 4.47213595499958*μ*abs_δ + 3.33333333333333*μ^2*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-7 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 250.0*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 670.820393249937*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-8 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 250.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^6*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2
    end

    if dorder_view==[5, 2, 0]
        func = 745.35599249993*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) + 745.35599249993*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) + 745.35599249993*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) + 745.35599249993*(-2 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) + 250.0*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 250.0*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 250.0*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 250.0*(-2 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 250.0*(-2 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 250.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 223.606797749979*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-3 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 223.606797749979*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 223.606797749979*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 111.80339887499*(-6 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 111.80339887499*(-6 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 111.80339887499*(-6 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 111.80339887499*(-6 - α)*(-2 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 111.80339887499*(-6 - α)*(-2 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 111.80339887499*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 250.0*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 111.80339887499*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 250.0*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 111.80339887499*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 250.0*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 111.80339887499*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 250.0*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 745.35599249993*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) - 745.35599249993*(-2 - α)*(-4 - α)*(1 + α)*(3 + α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) - 745.35599249993*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) - 111.80339887499*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 111.80339887499*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*dabs_δ^5*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^5*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 250.0*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 250.0*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 250.0*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)*(4.47213595499958*μ*dabs_δ + 6.66666666666667*μ^2*abs_δ*dabs_δ)/μ^2 - 111.80339887499*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 250.0*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 372.677996249965*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^5*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-5 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-5 - α) + 372.677996249965*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) + 223.606797749979*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*(-4 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 111.80339887499*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 111.80339887499*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2 + 4.47213595499958*μ*abs_δ + 3.33333333333333*μ^2*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-6 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 111.80339887499*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 250.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-7 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 111.80339887499*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2
    end

    if dorder_view==[4, 2, 0]
        func = 200.0*(-2 - α)*(-3 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α) + 200.0*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α) + 89.4427190999916*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 89.4427190999916*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 89.4427190999916*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 60.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-3 - α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 60.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 50.0*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 50.0*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 50.0*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 89.4427190999916*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 50.0*(-2 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 50.0*(-2 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 89.4427190999916*(-2 - α)*(-4 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 50.0*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 89.4427190999916*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 200.0*(-3 - α)*(1 + α)*(3 + α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α) - 200.0*(-2 - α)*(1 + α)*(3 + α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α) - 50.0*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 89.4427190999916*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 50.0*(-2 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 89.4427190999916*(-2 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 50.0*(-2 - α)*(-3 - α)*(-5 - α)*dabs_δ^4*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)*(4.47213595499958*μ*dabs_δ + 6.66666666666667*μ^2*abs_δ*dabs_δ)/μ^2 - 50.0*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^4*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 89.4427190999916*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 100.0*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^4*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-4 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-4 - α) + 100.0*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α) + 60.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 50.0*(-3 - α)*(-4 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 50.0*(-2 - α)*(-4 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 50.0*(-2 - α)*(-3 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2 + 4.47213595499958*μ*abs_δ + 3.33333333333333*μ^2*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-5 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 50.0*(-2 - α)*(-3 - α)*(-4 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 89.4427190999916*(-2 - α)*(-3 - α)*(-4 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-6 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 50.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2
    end

    if dorder_view==[3, 2, 0]
        func = 44.7213595499958*(-2 - α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-3 - α) + 30.0*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 13.4164078649987*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 22.3606797749979*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 22.3606797749979*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 30.0*(-3 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 22.3606797749979*(-2 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 30.0*(-2 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 44.7213595499958*(1 + α)*(3 + α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-3 - α) - 22.3606797749979*(-3 - α)*(-4 - α)*dabs_δ^3*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 30.0*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 22.3606797749979*(-2 - α)*(-4 - α)*dabs_δ^3*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 15.0*(-2 - α)*(-3 - α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)*(4.47213595499958*μ*dabs_δ + 6.66666666666667*μ^2*abs_δ*dabs_δ)/μ^2 - 22.3606797749979*(-2 - α)*(-3 - α)*dabs_δ^3*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 30.0*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 22.3606797749979*(-2 - α)*(1 + α)*(3 + α)*dabs_δ^3*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-3 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-3 - α) + 22.3606797749979*(-2 - α)*(1 + α)*(3 + α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-3 - α) + 13.4164078649987*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 22.3606797749979*(-3 - α)*(-4 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 22.3606797749979*(-2 - α)*(-4 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 11.180339887499*(-2 - α)*(-3 - α)*(-4 - α)*(2 + 4.47213595499958*μ*abs_δ + 3.33333333333333*μ^2*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 15.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-4 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 15.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 22.3606797749979*(-2 - α)*(-3 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 30.0*(-2 - α)*(-3 - α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 11.180339887499*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-5 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 22.3606797749979*(-2 - α)*(-3 - α)*(-4 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 11.180339887499*(-2 - α)*(-3 - α)*(-4 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2
    end

    if dorder_view==[2, 2, 0]
        func = 6.66666666666667*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-2 - α) + 10.0*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 8.94427190999916*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 2*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 - 10.0*(-3 - α)*dabs_δ^2*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 4.47213595499958*(-2 - α)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)*(4.47213595499958*μ*dabs_δ + 6.66666666666667*μ^2*abs_δ*dabs_δ)/μ^2 - 10.0*(-2 - α)*dabs_δ^2*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 8.94427190999916*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 3.33333333333333*(1 + α)*(3 + α)*dabs_δ^2*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-2 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-2 - α) + 3.33333333333333*(1 + α)*(3 + α)*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-2 - α) - 10.0*(-3 - α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 5.0*(-2 - α)*(-3 - α)*(2 + 4.47213595499958*μ*abs_δ + 3.33333333333333*μ^2*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 4.47213595499958*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-3 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 4.47213595499958*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 10.0*(-2 - α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 8.94427190999916*(-2 - α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 5.0*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-4 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 10.0*(-2 - α)*(-3 - α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 5.0*(-2 - α)*(-3 - α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2
    end

    if dorder_view==[1, 2, 0]
        func = (2.23606797749979*abs_δ + α/μ)^(-2 - α)*(4.47213595499958*μ*dabs_δ + 6.66666666666667*μ^2*abs_δ*dabs_δ)/μ^2 - 4.47213595499958*dabs_δ*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + (2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-2 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + (2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + 2*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + 2.23606797749979*(-2 - α)*(2 + 4.47213595499958*μ*abs_δ + 3.33333333333333*μ^2*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 4.47213595499958*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 2.23606797749979*(-2 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-3 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 4.47213595499958*(-2 - α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 2.23606797749979*(-2 - α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2
    end

    if dorder_view==[0, 2, 0]
        func = (2 + 4.47213595499958*μ*abs_δ + 3.33333333333333*μ^2*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + (α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(-2*1/(μ*(2.23606797749979*abs_δ + α/μ)) - (-2 - α)/(μ^2*(2.23606797749979*abs_δ + α/μ)^2))*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + 2*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + ((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))^2*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2
    end

    if dorder_view==[6, 1, 0]
        func = -1250.0*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) - 1250.0*(-2 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) - 1250.0*(-2 - α)*(-3 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) - 1250.0*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) - 335.410196624969*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 335.410196624969*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 335.410196624969*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 375.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 125.0*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*(-6 - α)*(-7 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 - 125.0*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 1250.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^6*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2 + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-8 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2
    end

    if dorder_view==[5, 1, 0]
        func = -372.677996249965*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) - 372.677996249965*(-2 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) - 372.677996249965*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) - 125.0*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 125.0*(-2 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 125.0*(-2 - α)*(-3 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 111.80339887499*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 55.9016994374948*(-6 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 55.9016994374948*(-6 - α)*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 - 55.9016994374948*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 372.677996249965*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) + 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^5*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-7 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2
    end

    if dorder_view==[4, 1, 0]
        func = -100.0*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α) - 100.0*(-2 - α)*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α) - 44.7213595499958*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 44.7213595499958*(-2 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 44.7213595499958*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 30.0*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*(-3 - α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 25.0*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 25.0*(-2 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 25.0*(-2 - α)*(-3 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 - 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 100.0*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α) + 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*dabs_δ^4*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*((-6 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2
    end

    if dorder_view==[3, 1, 0]
        func = -22.3606797749979*(1 + α)*(3 + α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-3 - α) - 15.0*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 15.0*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 6.70820393249937*(3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(-2 - α)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 11.180339887499*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 11.180339887499*(-2 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 - 11.180339887499*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 15.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 22.3606797749979*(-2 - α)*(1 + α)*(3 + α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-3 - α) + 11.180339887499*(-2 - α)*(-3 - α)*(-4 - α)*dabs_δ^3*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 15.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 11.180339887499*(-2 - α)*(-3 - α)*(-4 - α)*((-5 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2
    end

    if dorder_view==[2, 1, 0]
        func = (3.33333333333333*μ^2*(1 + α)*dabs_δ^2 + 3.33333333333333*μ^2*(3 + α)*dabs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 - 4.47213595499958*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 - 5.0*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 - 5.0*(-2 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 4.47213595499958*(-2 - α)*(2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 3.33333333333333*(1 + α)*(3 + α)*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-2 - α) + 5.0*(-2 - α)*(-3 - α)*dabs_δ^2*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 4.47213595499958*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 5.0*(-2 - α)*(-3 - α)*((-4 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2
    end

    if dorder_view==[1, 1, 0]
        func = (2.23606797749979*α*μ*dabs_δ + 2.23606797749979*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*abs_δ*dabs_δ + 3.33333333333333*μ^2*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 - 2.23606797749979*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + (2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + 2.23606797749979*(-2 - α)*dabs_δ*(α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 2.23606797749979*(-2 - α)*((-3 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2
    end

    if dorder_view==[0, 1, 0]
        func = (α + α*(1 + 2.23606797749979*μ*abs_δ) + 2.23606797749979*μ*(2 + α)*abs_δ + 1.66666666666667*μ^2*(1 + α)*abs_δ^2 + 1.66666666666667*μ^2*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + ((-2 - α)/(μ*(2.23606797749979*abs_δ + α/μ)) - log(2.23606797749979*abs_δ + α/μ))*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2
    end

    if dorder_view==[6, 0, 0]
        func = 1250.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(1 + α)*(3 + α)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-6 - α) + 335.410196624969*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2 + 125.0*(-6 - α)*(-7 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^6*(2.23606797749979*abs_δ + α/μ)^(-8 - α)/μ^2
    end

    if dorder_view==[5, 0, 0]
        func = 372.677996249965*(-2 - α)*(-3 - α)*(-4 - α)*(1 + α)*(3 + α)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-5 - α) + 125.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2 + 55.9016994374948*(-6 - α)*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^5*(2.23606797749979*abs_δ + α/μ)^(-7 - α)/μ^2
    end

    if dorder_view==[4, 0, 0]
        func = 100.0*(-2 - α)*(-3 - α)*(1 + α)*(3 + α)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-4 - α) + 44.7213595499958*(-2 - α)*(-3 - α)*(-4 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2 + 25.0*(-2 - α)*(-3 - α)*(-4 - α)*(-5 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^4*(2.23606797749979*abs_δ + α/μ)^(-6 - α)/μ^2
    end

    if dorder_view==[3, 0, 0]
        func = 22.3606797749979*(-2 - α)*(1 + α)*(3 + α)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-3 - α) + 15.0*(-2 - α)*(-3 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2 + 11.180339887499*(-2 - α)*(-3 - α)*(-4 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^3*(2.23606797749979*abs_δ + α/μ)^(-5 - α)/μ^2
    end

    if dorder_view==[2, 0, 0]
        func = 3.33333333333333*(1 + α)*(3 + α)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-2 - α) + 4.47213595499958*(-2 - α)*(2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2 + 5.0*(-2 - α)*(-3 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ^2*(2.23606797749979*abs_δ + α/μ)^(-4 - α)/μ^2
    end

    if dorder_view==[1, 0, 0]
        func = (2.23606797749979*α*μ*(2 + α)*dabs_δ + 3.33333333333333*μ^2*(1 + α)*(3 + α)*abs_δ*dabs_δ)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2 + 2.23606797749979*(-2 - α)*(α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*dabs_δ*(2.23606797749979*abs_δ + α/μ)^(-3 - α)/μ^2
    end

    if dorder_view==[0, 0, 0]
        func = (α*(α + 2.23606797749979*μ*(2 + α)*abs_δ) + 1.66666666666667*μ^2*(1 + α)*(3 + α)*abs_δ^2)*(2.23606797749979*abs_δ + α/μ)^(-2 - α)/μ^2
    end

    dorder[2] = dorder2  # resetting dorder[2]
    return powers_of_negative_one(dorder2) * float(func)  # correcting for amount of t2 derivatives

end


return rm52_kernel, 2  # the function handle and the number of kernel hyperparameters
